You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@cordova.apache.org by ag...@apache.org on 2013/01/15 19:23:15 UTC

js commit: [CB-2213] Added DestinationType.NATIVE_URI.

Updated Branches:
  refs/heads/master ba7edf04b -> 1f2323a5a


[CB-2213] Added DestinationType.NATIVE_URI.


Project: http://git-wip-us.apache.org/repos/asf/cordova-js/repo
Commit: http://git-wip-us.apache.org/repos/asf/cordova-js/commit/1f2323a5
Tree: http://git-wip-us.apache.org/repos/asf/cordova-js/tree/1f2323a5
Diff: http://git-wip-us.apache.org/repos/asf/cordova-js/diff/1f2323a5

Branch: refs/heads/master
Commit: 1f2323a5ad9118873ef77bc3ffa83d9970ba36c1
Parents: ba7edf0
Author: Max Woghiren <ma...@gmail.com>
Authored: Mon Jan 14 17:20:06 2013 -0500
Committer: Andrew Grieve <ag...@chromium.org>
Committed: Tue Jan 15 13:23:03 2013 -0500

----------------------------------------------------------------------
 lib/common/plugin/CameraConstants.js |    3 ++-
 1 files changed, 2 insertions(+), 1 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/cordova-js/blob/1f2323a5/lib/common/plugin/CameraConstants.js
----------------------------------------------------------------------
diff --git a/lib/common/plugin/CameraConstants.js b/lib/common/plugin/CameraConstants.js
index 4b6cdda..ac23926 100644
--- a/lib/common/plugin/CameraConstants.js
+++ b/lib/common/plugin/CameraConstants.js
@@ -22,7 +22,8 @@
 module.exports = {
   DestinationType:{
     DATA_URL: 0,         // Return base64 encoded string
-    FILE_URI: 1          // Return file uri (content://media/external/images/media/2 for Android)
+    FILE_URI: 1,         // Return file uri (content://media/external/images/media/2 for Android)
+    NATIVE_URI: 2        // Return native uri (eg. asset-library://... for iOS)
   },
   EncodingType:{
     JPEG: 0,             // Return JPEG encoded image